@@ -16,15 +16,20 @@ mod promote;
 
 pub use self::create::CreateLabel;
 pub use self::create::CreateLabelBuilder;
+pub use self::create::CreateLabelBuilderError;
 
 pub use self::label::Label;
 pub use self::label::LabelBuilder;
+pub use self::label::LabelBuilderError;
 
 pub use self::labels::Labels;
 pub use self::labels::LabelsBuilder;
+pub use self::labels::LabelsBuilderError;
 
 pub use self::delete::DeleteLabel;
 pub use self::delete::DeleteLabelBuilder;
+pub use self::delete::DeleteLabelBuilderError;
 
 pub use self::promote::PromoteLabel;
 pub use self::promote::PromoteLabelBuilder;
+pub use self::promote::PromoteLabelBuilderError;
